@@ -1,5 +1,5 @@
 
-;; Copyright (C) 2020, 2022, 2023 Tommi Höynälänmaa
+;; Copyright (C) 2020, 2022-2024 Tommi Höynälänmaa
 
 ;; This file is part of Theme-D-Intr.
 
@@ -44,7 +44,4 @@
   (Adw MessageDialog))
  (rejected-methods
   append map get-style activate compare copy get-cursor free
-  get-name get-state apply)
- (overridden-functions			     
-  (g-application-run (<g-application> (:uniform-list <string>))
-		     <integer> nonpure)))
+  get-name get-state apply))
